#
# spec file for package xed
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xed
Version:        3.4.5
Release:        1.3
Summary:        A text editor with highlighting
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/linuxmint/xed
Source:         https://github.com/linuxmint/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gnome-common
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(enchant)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-4)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xapp)
Requires:       xapps-common
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
xed is a text editor designed for the Cinnamon desktop. It has most
standard text editor functions and supports international text in
Unicode. Advanced features include syntax highlighting and automatic
indentation of source code, printing and editing of multiple
documents in one window.

xed is extensible through a plugin system, which currently
includes support for spell checking, comparing files, viewing VCS
ChangeLogs, and adjusting indentation levels.

%package devel
Summary:        Development files for Xed, a text editor
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(gtksourceview-3.0)

%description devel
xed is a text editor designed for the Cinnamon desktop. It has most
standard text editor functions and supports international text in
Unicode. Advanced features include syntax highlighting and automatic
indentation of source code, printing and editing of multiple
documents in one window.

xed is extensible through a plugin system, which currently
includes support for spell checking, comparing files, viewing VCS
ChangeLogs, and adjusting indentation levels.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
chmod -x %{buildroot}/%{_includedir}/%{name}/xed-searchbar.h
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%post
/sbin/ldconfig
%if 0%{?suse_version} < 1500
%desktop_database_post
%glib2_gsettings_schema_post
%endif

%postun
/sbin/ldconfig
%if 0%{?suse_version} < 1500
%desktop_database_postun
%glib2_gsettings_schema_postun
%endif

%files
%license COPYING
%doc AUTHORS README.md debian/changelog
%{_bindir}/%{name}
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/gir-1.0/
%{_libdir}/%{name}/
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/metainfo/xed.appdata.xml
%{_datadir}/dbus-1/services/org.x.editor.service
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_datadir}/help/C/%{name}/

%files devel
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/gir-1.0/

%files lang -f %{name}.lang

%changelog
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 3.4.5:
  * Update xed-metadata-manager.c
  * l10n: Update translations
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 3.4.4:
  * l10n: Update translations
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 3.4.3:
  * l10n: Update translations
  * Revert "dark mode: Delegate to libxapp"
  * l10n: Update POT
  * l10n: Update translations
  * xed (3.4.0) victoria; urgency=medium
  * Save correct window size on exit
  * dark mode: Delegate to libxapp
  * Fix build.
  * l10n: Update POT
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.8:
  * Use github actions for CI builds.
  * minimap: Use a smaller font size.
  * minimap: Use wide size by default
  * l10n: Update translations
  * textsize plugin: Fix extra accelerator bindings.
  * Update xed-time-plugin.c
  * *backporting* the replace (all) shortcuts from gedit to xed - issue no.
  * xed-searchbar.ui: enable mnemonic accelerator behavior for previous commit.
* Tue Jan 25 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 3.2.2.
  * l10n: Update translations
  * Add missing type cast check (#507)
- Updates to version 3.2.1.
  * Update translations
- Updates to version 3.2.0.
  * docs: Update reference and small fixes (#470)
  * Delete xed-prefs-manager-private.h (not used) (#471)
  * Packaging: remove zenity dependency (#472)
  * Add Ctrl+Tab and Ctrl+Shift+Tab keybindings to notebook
  * l10n: Update POT
  * Add an option to hide the menubar
  * meson.build: keep temporary files between builds
- Updates to version 3.0.2.
  * l10n: Update translations
- Updates to version 3.0.1.
  * l10n: Update translations
* Thu Jun  3 2021 andy great <andythe_great@pm.me>
- Update to version 3.0.0.
  * Fix various typos in index.docbook
  * Fix permissions
  * Implement #225: Options to render whitespace
  * i18n: Don't translate gsettings strings.
  * Fix crashes when no documents (tabs) are open
  * Uses strtol instead of atoi so that we can properly handle errors.
  * Use CLAMP macro instead
  * l10n: Update POT
* Fri Mar  5 2021 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 2.8.4.
  * fixup! cleanup: remove code dropped in commit 67892da099357e24b3fd3c31fa758947b1dfc47a
  * l10n: Update translations
* Sat Dec 26 2020 andy great <andythe_great@pm.me>
- Update to version 2.8.3.
  * Packaging: Add missing dependency on gir1.2-gtksource-4
- Updates for version 2.8.2.
  * l10n: Update translations
* Tue Dec  8 2020 andy great <andythe_great@pm.me>
- Update to version 2.8.1.
  * cleanup: remove code dropped
  * remove never-used variable added
  * bracketcompletion: Enable plugin by default
  * Remove links in plugin about dialogs
- Updates for 2.8.0.
  * Port to Gtksourceview4
  * Add a new window desktop action
  * plugins: Clean up deprecated preprcessor commands
  * Clean up remaining deprecated preprocessor commands
  * xed-highlight-mode-selector.c: Fix a couple of missing casts
  * textsize plugin: Zoom text regardless of selection
  * xed-highlight-mode-dialog/selector: Clean up code style
  * xed-completion-plugin.c: Clean up the code style
  * auto bracket complete feature   - added bracket-complete dir
    in plugins   - gtksourceview min depedency change to 4.0.3
  * Add XAppFavorites support to the file menu.
  * meson.build: bump xapp version.
  * l10n: Update POT
* Sun Sep 13 2020 andy great <andythe_great@pm.me>
- Update to version 2.6.2.
  * No important change.
* Fri Mar 27 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 2.4.2:
  * Update translations
* Sun Jul 28 2019 Marguerite Su <i@marguerite.su>
- Update to version 2.2.2:
  * Automatically open new Xed window on current workspace if
    it wasn't already opened. Otherwise, open new tab in Xed
    window on current workspace
  * Preferences: Make dialog slightly taller
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.2.0:
  * meson: require itstool command to be available (#266)
  * statusbar: Fix the menu button styling (#281)
  * cleanup: Remove an unused Makefile.am (#280)
  * print preview: fix layout drawing for 1X2 and 2X1 layouts (#291)
  * Filebrowser: Kill the click policy property with fire (#293)
  * xed-window: Fix the tabs/spaces label in the statusbar (#283)
  * xed-notebook: Always show the main notebook tabs (#285)
  * Fix some deprecation warnings (#289)
  * print preview: fix logic for forward button sensitivity (#292)
  * Add toggle comment and toggle comment block actions w/ keybindings (#290)
  * l10n: Update POT
  * print job: replace some deprecated font button functions (#294)
  * Replace deprecated gdk_cursor_new with gdk_cursor_new_for_display (#295)
  * Print preview: remove a couple calls to gtk_adjustment_value_changed (#296)
  * Search: replace a few functions that were deprecated in Gtk 3.22 (#297)
  * Fix stuttering and disappearing of the toolbar when fullscreen (#300)
  * Switch deprecated gtk_icon_info_free to g_object_unref (#301)
  * Remove references to deprecated GTK_STOCK_* (#298)
  * Remove deprecated call to gtk_widget_override_background_color (#299)
  * Tab width popup: only select a menu item when the menu is open (#311)
  * Simplify an if statement. The logic is identical, but easier to read (#314)
  * Add minimum required version for xapp (#313)
  * Prevent a warning when closing the window while print preview is open (#315)
* Fri Mar 15 2019 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 2.0.2:
  * Fix non-translated desktop file
  * highlight mode window:  Make activatable via shortcut (ctrl-shift-H), focus the search entry by default, and allow Escape to cancel the dialog from the search entry.
  * Fix warnings when building xed 2.0.1 (#264)
  * l10n: Update translations
  * Switch build instructions for meson port. (#263)
  * l10n: Update translations
  * Import GeditHighlightModeDialog and -Selector from Gedit to Xed.
  * Use highlight dialog instead submenu in "View" menu.
  * XedWindow cleanup.
  * Import GeditStatusMenuButton.
  * Fix compilation warning.
  * Use popover with highlight selector instead loooong menu in statusbar.
  * Use XedStatusMenuButton instead -ComboBox in statusbar, for consistency.
  * Kill XedStatusComboBox. It's not used now.
  * xed-window: Indicate if we are currently using spaces or tabs in statusbar (#246)
  * Use icon for keyboard shortcuts help entry (#255)
  * Rearrange help entries (xapp consistency) (#256)
  * close dialog: use "suggested-action" style class (#261)
  * Port to meson (#258)
  * Fix merge issues
  * l10n: Update POT
* Fri Jul 20 2018 sor.alexei@meowr.ru
- Update to version 1.8.3:
  * search bar/xed-history-entry: Set a "width-chars" on the
    GtkEntry widgets of the search and replace entry widgets, and
    allow their labels to ellipsise upon resizing.
* Tue Jun 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.2:
  * Update translations.
* Sat May 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.1:
  * Update translations.
* Tue May  8 2018 sor.alexei@meowr.ru
- Update to version 1.8.0:
  * Fix clang compile issue.
  * Fix Py*DeprecationWarning.
  * Pull upstream fixes for gtk and gtksourceview changes.
  * preferences-dialog: Complete revamp.
  * xed-window: Rework the fullscreen toolbar.
  * xed-status-combo-box: Remove some deprecated css functionality.
  * xed-view-frame: Fix the css for the minimap frame.
  * xed-notebook: Clean up some gtk3.20+ conditionals.
  * Add a shortcuts window.
  * xed-view: Add shortcuts for change case.
  * css: Add support for Adwaita.
  * xed-searchbar: Fix the size of the searchbar close button.
  * xed-spell-checker.c: Clean up the code formatting.
  * spell-plugin: Update for removal of some deprecated
    functionality.
  * xed-notebook: Allow changing tabs with mouse back/forward
    buttons.
  * Clean up a few build warnings.
  * spell-plugin: Port to gspell.
  * spell-plugin: Fix a link to the help file.
  * Add C tags to the taglist plugin.
  * xed-window: Fix a potential crash.
  * Creation of plugin Word completion.
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 1.6.3:
  * Update translations.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 1.6.2:
  * xed-status-combo-box: Simplify the widget heirarchy.
* Wed Nov 15 2017 sor.alexei@meowr.ru
- Update to version 1.6.1:
  * Fix localisation in the TextSize plugin.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 1.6.0:
  * text zoom: Put a limit on the min and max zoom.
  * Make the trailsave plugin also strip trailing lines.
  * Don't present users with the hidden highlight languages.
  * xed-view: Fix a crash when right clicking the left gutter.
  * Minimap.
  * Update translations.
- Move the .gir file to the devel package.
* Sun Jul 23 2017 sor.alexei@meowr.ru
- Update to version 1.4.6:
  * Use the correct value to save the window state in GSettings.
* Sun Jul  9 2017 sor.alexei@meowr.ru
- Update to version 1.4.5:
  * Create ISSUE_TEMPLATE.md.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 1.4.4:
  * Update translations.
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 1.4.3:
  * Fix an ugly white border on GTK+ 3.20 and newer.
  * filebrowser: Change an icon name.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.4.2:
  * Fix the gtksourceprintcompositor.h includes warning.
  * Update translations.
* Wed May 10 2017 jengelh@inai.de
- Remove wrong claims in description.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.4.1 (changes since 1.2.2):
  * Search: Don't jump to the next result when toggling search
    options.
  * Clean up some deprecations.
  * plugins: Drop support for old style python plugins.
  * Build GObject introspection data.
  * Fix some introspection warnings.
  * Remove a couple of invalid annotations.
  * Drop some leftover 2.xx comments from gnome/pluma.
  * Port plugin system to libpeas.
  * Remove old plugin system and docs for it.
  * taglist plugin: Don't look for taglist in non-existing legacy
    directories.
  * xed-panel: Clean up the layout of the panels.
  * Add buttons to the statusbar to show/hide the panels.
  * xed-panel: Remove the header and close button.
  * xed-panel: Simplify panel building a bit.
  * xed-panel: Move the notebook tabs to the top.
  * Add a few style classes.
  * Add view menu entry for word wrap.
  * Allow scrolling on notebook tabs to change the active page.
  * xed-prefs-manager-app: Remove some leftover logging.
  * notebooks: Don't show tabs when the notebook only has one page.
  * xed-window: Use a better icon for the documents panel tab.
  * xed-print-preview.c: Restyle the tool bar.
  * Add new (App/Window/View)Activatable interfaces for plugins.
  * Update plugins for the WindowActivatable changes.
  * Port to the use of GFile instead of URIs and merge gio document
    loader and saver into document loader and saver.
  * Revamp our handling of settings.
  * Clean up the docs a bit.
  * Redesign the goto line popup dialogue.
  * xed-preferences-dialog: Fix a setting having the wrong
    sensitiviy.
  * tests: Fix to use GFile instead of uris.
  * Merge smart converter in the document output stream.
  * xed-document-output-stream: Factor out validate_and_insert
    method.
  * Pull some upstream changes from Gedit in prep for using more of
    the GtkSource* backend.
  * Remove the xed style scheme manager instance.
  * xed-document: Fix a couple of possible memory leaks.
  * Kill xed-language-manager and use gtksourcelanguagemanager
    directly.
  * xed-document: Rework externally modified/deleted check.
  * Remove xed_utils_location_has_file_scheme.
  * Clean up our GSettings use a bit more.
  * Port to the GtkSourceView search functionality.
  * Add _xed_document_needs_saving.
  * Plugins: Remove the changecase plugin.
  * Port to GtkSource* API.
  * Port xed to dbus and GtkApplication.
  * message-area: Rename message area to info bar.
  * info-bar: Don't use icons in buttons.
  * xed-progress-info-bar: Properly expand the progress bar.
  * Remove the dialogue utility library.
  * Start using GResource.
  * Set textdomain as soon as possible.
  * Don't use global vars for command line parsing.
  * xed-app: Handle also application::open.
  * xed-app: Shutdown metadata-manager after GTK+.
  * xed-window: Fix getting the wrong window size when cloning a
    window.
  * Add a preference to allow using the dark variant of a theme if
    available.
  * xed-view: Add some margin to the top and left of the text view.
  * prefs-dialog: Fix a crash when removing style schemes.
  * docs: Start cleaning up the docs.
  * Implement font zooming in the editor.
  * Sort: Turn sort into a simpler and undoable action.
  * Focus view when opening files from the filebrowser or documents
    panel.
  * Fix g_free() which should be g_object_unref() in file browser.
  * Use slice allocator instead of g_new() when appropriate.
  * xed-file-browser-widget: Clean up code styling.
  * filebrowser-view: Removed the unused "busy" cursor.
  * Do not leak file info for . and .. dirs.
  * filebrowser: Unref the enumerator in the filebrowser plugin.
  * filebrowser: Don't leak GFiles.
  * filebrowser: Fix crash on open_terminal action.
  * filebrowser: Remove the back and forward toolbar dropdowns.
  * filebrowser: Support new location of gtk bookmarks file.
  * filebrowser: "Rename" menu entry should have an ellipsis.
  * filebrowser: use Untitled File/Folder for new
    file/directories.
  * filebrowser: Redesign the toolbar in filebrowser.
  * filebrowser: Activate selected item when search is complete.
  * filebrowser: Do not parse .hidden in the file browser.
  * filebrowser: Make the "Open terminal here" command work again.
  * filebrowser: Set the combobox insensitive when the bookmarks
    are showing.
  * Fix calling set_command_line_wait().
  * Allow building with --disable-spell.
  * Focus a tab when attempting to close it with unsaved changes.
  * Add a new animated xed-paned.
  * xed-commands-view: Clean up code style.
  * time-plugin: Use GDateTime.
  * Clean up styling a bit.
  * Use GtkApplication inhibit API.
  * Fix "gedit" occurence.
  * Depend on gtksourceview-3.0 >= 3.14.0.
  * Only use gtk_text_view_set_top_margin() with GTK+ 3.18+.
  * Fix po/POTFILES.in and generate POT file.
  * Fix FSF address.
  * Update translations.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 1.2.2:
  * searchbar: Add a close button.
  * searchbar: Make sure we clear highlighting when the last
    character is removed.
  * Search: Fix search jumping to next result while typing.
  * Search: Perform a search when case-sensitive or entire-word
    buttons are clicked.
  * Update translations.
* Thu Nov 10 2016 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Update translations.
* Wed Nov  2 2016 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * configure: Don't require passing --with-gtk=3.0 to build.
  * Add "notepad" to the list of menu item keywords.
  * When running as root, add an infobar to warn about
    Elevated Privileges.
  * Toolbar: Don't emphasise toolbar items (save, open, undo).
  * Give Xed a Sublime-like searchbar.
  * Reformat code to conform to Mint coding style.
  * Default Settings: Change line width to 120 chars and enable
    "insert-spaces".
  * toolbar: Revamp the main toolbar style.
  * ui: Convert the remaining actions to use symbolic icons.
  * prefs: Remove now unused toolbar style prefs.
  * ui: Don't hide the main notebook tabs in fullscreen.
  * xed-close-button: Convert to using a symbolic icon.
  * filebrowser-plugin: Convert most icons to symbolic icons.
  * Update the pot file.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.6:
  * xed-notebook.c: Check vertical mouse position when determining
    whether a tab is being manipulated. We were just checking
    horizontal position, which meant that depending on where you
    start a drag-and-drop, it might think you're trying to drag a
    tab instead, causing undesirable behaviour.
  * Update translations.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 1.0.5:
  * Update translations.
* Wed Apr 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.4 (changes since 1.0.2):
  * Fix wrong dconf paths.
  * Switch to gnome-common.
  * Fix few build warnings.
  * GTK+ 3.10 compatibility.
  * notebooks: Remove the extra frame from the main and documents
    panel scrolled windows.
  * Use Ctrl+Y for Redo.
  * Update translations.
* Sun Feb  7 2016 sor.alexei@meowr.ru
- Initial package, based on pluma's package.
